package com.ruoyi.system.controller;

import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PutMapping;
import com.ruoyi.common.security.utils.SecurityUtils;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.validation.annotation.Validated;
import java.util.ArrayList;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.web.domain.AjaxResult;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import javax.servlet.http.HttpServletResponse;
import org.springframework.web.bind.annotation.GetMapping;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import java.util.List;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.system.api.domain.SysDictData;
import com.ruoyi.system.service.ISysDictTypeService;
import org.springframework.beans.factory.annotation.Autowired;
import com.ruoyi.system.service.ISysDictDataService;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.core.web.controller.BaseController;

@RestController
@RequestMapping({ "/dict/data" })
public class SysDictDataController extends BaseController
{
    @Autowired
    private ISysDictDataService dictDataService;
    @Autowired
    private ISysDictTypeService dictTypeService;
    
    @RequiresPermissions({ "system:dict:list" })
    @GetMapping({ "/list" })
    public TableDataInfo list(final SysDictData dictData) {
        this.startPage();
        final List<SysDictData> list = this.dictDataService.selectDictDataList(dictData);
        return this.getDataTable((List)list);
    }
    
    @Log(title = "字典数据", businessType = BusinessType.EXPORT)
    @RequiresPermissions({ "system:dict:export" })
    @PostMapping({ "/export" })
    public void export(final HttpServletResponse response, final SysDictData dictData) {
        final List<SysDictData> list = this.dictDataService.selectDictDataList(dictData);
        final ExcelUtil<SysDictData> util = (ExcelUtil<SysDictData>)new ExcelUtil((Class)SysDictData.class);
        util.exportExcel(response, (List)list, "字典数据");
    }
    
    @RequiresPermissions({ "system:dict:query" })
    @GetMapping({ "/{dictCode}" })
    public AjaxResult getInfo(@PathVariable final Long dictCode) {
        return this.success((Object)this.dictDataService.selectDictDataById(dictCode));
    }
    
    @GetMapping({ "/type/{dictType}" })
    public AjaxResult dictType(@PathVariable final String dictType) {
        List<SysDictData> data = this.dictTypeService.selectDictDataByType(dictType);
        if (StringUtils.isNull((Object)data)) {
            data = new ArrayList<SysDictData>();
        }
        return this.success((Object)data);
    }
    
    @RequiresPermissions({ "system:dict:add" })
    @Log(title = "字典数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody final SysDictData dict) {
        dict.setCreateBy(SecurityUtils.getUsername());
        return this.toAjax(this.dictDataService.insertDictData(dict));
    }
    
    @RequiresPermissions({ "system:dict:edit" })
    @Log(title = "字典数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody final SysDictData dict) {
        dict.setUpdateBy(SecurityUtils.getUsername());
        return this.toAjax(this.dictDataService.updateDictData(dict));
    }
    
    @RequiresPermissions({ "system:dict:remove" })
    @Log(title = "字典类型", businessType = BusinessType.DELETE)
    @DeleteMapping({ "/{dictCodes}" })
    public AjaxResult remove(@PathVariable final Long[] dictCodes) {
        this.dictDataService.deleteDictDataByIds(dictCodes);
        return this.success();
    }
}
